@@ -20,11 +20,11 @@
 #include <ignition/msgs.hh>
 
 #include "gtest/gtest.h"
-#include "gz/transport/Node.hh"
-#include "gz/transport/TransportTypes.hh"
-#include "gz/transport/test_config.h"
+#include "ignition/transport/Node.hh"
+#include "ignition/transport/TransportTypes.hh"
+#include "ignition/transport/test_config.h"
 
-using namespace gz;
+using namespace ignition;
 
 static std::string partition;  // NOLINT(*)
 static std::string g_FQNPartition;  // NOLINT(*)
@@ -51,7 +51,7 @@ void reset()
 
 //////////////////////////////////////////////////
 /// \brief Function called each time a topic update is received.
-void cb(const msgs::Int32 &/*_msg*/)
+void cb(const ignition::msgs::Int32 &/*_msg*/)
 {
   cbExecuted = true;
   ++counter;
@@ -59,8 +59,8 @@ void cb(const msgs::Int32 &/*_msg*/)
 
 //////////////////////////////////////////////////
 /// \brief Function called each time a topic update is received.
-void cbInfo(const msgs::Int32 &_msg,
-            const transport::MessageInfo &_info)
+void cbInfo(const ignition::msgs::Int32 &_msg,
+            const ignition::transport::MessageInfo &_info)
 {
   EXPECT_EQ(_info.Topic(), g_topic);
   EXPECT_EQ(g_FQNPartition, _info.Partition());
@@ -80,7 +80,7 @@ void genericCb(const transport::ProtoMsg &/*_msg*/)
 
 //////////////////////////////////////////////////
 /// \brief Callback for receiving Vector3d data.
-void cbVector(const msgs::Vector3d &/*_msg*/)
+void cbVector(const ignition::msgs::Vector3d &/*_msg*/)
 {
   cbVectorExecuted = true;
   ++counter;
@@ -88,7 +88,7 @@ void cbVector(const msgs::Vector3d &/*_msg*/)
 
 //////////////////////////////////////////////////
 void cbRaw(const char * /*_msgData*/, const size_t /*_size*/,
-           const transport::MessageInfo &/*_info*/)
+           const ignition::transport::MessageInfo &/*_info*/)
 {
   cbRawExecuted = true;
   ++counter;
@@ -102,7 +102,7 @@ void cbRaw(const char * /*_msgData*/, const size_t /*_size*/,
 TEST(twoProcPubSub, PubSubTwoProcsThreeNodes)
 {
   transport::Node node;
-  auto pub = node.Advertise<msgs::Vector3d>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Vector3d>(g_topic);
   EXPECT_TRUE(pub);
 
   // No subscribers yet.
@@ -115,7 +115,7 @@ TEST(twoProcPubSub, PubSubTwoProcsThreeNodes)
   testing::forkHandlerType pi = testing::forkAndRun(subscriberPath.c_str(),
     partition.c_str());
 
-  msgs::Vector3d msg;
+  ignition::msgs::Vector3d msg;
   msg.set_x(1.0);
   msg.set_y(2.0);
   msg.set_z(3.0);
@@ -141,7 +141,7 @@ TEST(twoProcPubSub, PubSubTwoProcsThreeNodes)
 TEST(twoProcPubSub, RawPubSubTwoProcsThreeNodes)
 {
   transport::Node node;
-  auto pub = node.Advertise<msgs::Vector3d>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Vector3d>(g_topic);
   EXPECT_TRUE(pub);
 
   // No subscribers yet.
@@ -154,7 +154,7 @@ TEST(twoProcPubSub, RawPubSubTwoProcsThreeNodes)
   testing::forkHandlerType pi = testing::forkAndRun(subscriberPath.c_str(),
     partition.c_str());
 
-  msgs::Vector3d msg;
+  ignition::msgs::Vector3d msg;
   msg.set_x(1.0);
   msg.set_y(2.0);
   msg.set_z(3.0);
@@ -170,8 +170,7 @@ TEST(twoProcPubSub, RawPubSubTwoProcsThreeNodes)
   // Publish messages for a few seconds
   for (auto i = 0; i < 10; ++i)
   {
-    EXPECT_TRUE(pub.PublishRaw(msg.SerializeAsString(),
-          std::string(msg.GetTypeName())));
+    EXPECT_TRUE(pub.PublishRaw(msg.SerializeAsString(), msg.GetTypeName()));
     std::this_thread::sleep_for(std::chrono::milliseconds(500));
   }
 
@@ -221,7 +220,7 @@ TEST(twoProcPubSub, PubRawSubWrongTypesOnSubscription)
 
   transport::Node node;
   EXPECT_TRUE(node.SubscribeRaw(g_topic, cbRaw,
-                                std::string(msgs::Int32().GetTypeName())));
+                                ignition::msgs::Int32().GetTypeName()));
 
   // Wait some time before publishing.
   std::this_thread::sleep_for(std::chrono::milliseconds(1500));
@@ -320,7 +319,7 @@ TEST(twoProcPubSub, PubSubWrongTypesTwoRawSubscribers)
   transport::Node node3;
   EXPECT_TRUE(node1.SubscribeRaw(g_topic, wrongCb, "wrong.msg.type"));
   EXPECT_TRUE(node2.SubscribeRaw(g_topic, correctCb,
-                                 std::string(msgs::Vector3d().GetTypeName())));
+                                 msgs::Vector3d().GetTypeName()));
   EXPECT_TRUE(node3.SubscribeRaw(g_topic, genericCb));
 
 
@@ -376,7 +375,7 @@ TEST(twoProcPubSub, SubThrottled)
   std::this_thread::sleep_for(std::chrono::milliseconds(500));
 
   transport::Node node;
-  transport::SubscribeOptions opts;
+  ignition::transport::SubscribeOptions opts;
   opts.SetMsgsPerSec(1u);
   EXPECT_TRUE(node.Subscribe(g_topic, cb, opts));
 
@@ -533,59 +532,6 @@ TEST(twoProcPubSub, TopicInfo)
   testing::waitAndCleanupFork(pi);
 }
 
-//////////////////////////////////////////////////
-/// \brief Two different nodes running in two different processes. The
-/// publisher in the main process here publishes a message to the
-/// remote subscriber in the other process before immediately going
-/// out of scope. The subscriber in the other process then unsubscribes to
-/// the topic. The test verifies that the publisher node in the main process
-/// is able to correctly remove its remote subscribers in the case that the
-/// publisher is destroyed before the subscriber so that HasConnections()
-/// check returns the correct result.
-TEST(twoProcPubSub, PubSubTwoProcsScopedPub)
-{
-  transport::Node node;
-
-  for (auto j = 0; j < 2; ++j)
-  {
-    // Start subscriber process before a publisher is created
-    std::string subscriberPath = testing::portablePathUnion(
-      IGN_TRANSPORT_TEST_DIR, "INTEGRATION_twoProcsPubSubSingleSubscriber_aux");
-
-    testing::forkHandlerType pi = testing::forkAndRun(subscriberPath.c_str(),
-      partition.c_str());
-
-    // Sleep for subscriber process to fully come up
-    std::this_thread::sleep_for(std::chrono::milliseconds(500));
-
-    // Reduce the publisher scope so that it is destroyed before the subscriber
-    // process ends.
-    {
-      auto pub = node.Advertise<msgs::Vector3d>(g_topic);
-      EXPECT_TRUE(pub);
-
-      // No subscribers yet right after pub comes up because it takes time for
-      // it to discover subscribers on the network
-      EXPECT_FALSE(pub.HasConnections());
-
-      std::this_thread::sleep_for(std::chrono::milliseconds(100));
-
-      // Now, we should have subscribers.
-      EXPECT_TRUE(pub.HasConnections());
-
-      msgs::Vector3d msg;
-      msg.set_x(1.0);
-      msg.set_y(2.0);
-      msg.set_z(3.0);
-
-      EXPECT_TRUE(pub.Publish(msg));
-    }
-
-    std::this_thread::sleep_for(std::chrono::milliseconds(100));
-    testing::waitAndCleanupFork(pi);
-  }
-}
-
 //////////////////////////////////////////////////
 int main(int argc, char **argv)
 {
